==> dde-launcher_4.6.13.orig.tar.xz: dde-launcher-4.6.13/translations/dde-launcher_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ca" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>No hi ha resultats de la cerca.</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Xat</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Gràfics</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Oficina</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Lectura</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Desenvolupament</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <source>Games</source>
        <translation>Jocs</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Altres</translation>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmeu-ho</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation>Segur que voleu desinstal·lar %1?</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>Elimina de l&apos;escriptori</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>Elimina de l&apos;acoblador</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>Desinstal·la</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation>Inhabilita l&apos;escalatge de la pantalla</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Obre</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>Enviar a l&apos;escriptori</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>Enviar al dock</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>Eliminar de l&apos;arrencada</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>Afegir a l&apos;arrencada</translation>
    </message>
    <message>
        <source>Use a proxy</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation>Totes les aplicacions</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Xat</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Gràfics</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Jocs</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Oficina</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Lectura</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Desenvolupament</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Altres</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>Ordinador</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documents</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Imatges</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Baixades</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Bloqueja</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Surt</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reinicia</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspèn</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Atura</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Enrere</translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>Ordinador</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Atura</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Bloqueja</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Surt</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reinicia</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspèn</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Enrere</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documents</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Imatges</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Baixades</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>Ordinador</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Baixades</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configuració</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Imatges</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documents</translation>
    </message>
    <message>
        <source>Power</source>
        <translation>Energia</translation>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation>Totes les categories</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Enrere</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmeu-ho</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation>Segur que voleu desinstal·lar %1?</translation>
    </message>
</context>
</TS>

==> dde-launcher_5.0.14.orig.tar.xz: dde-launcher-5.0.14/translations/dde-launcher_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ca" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>No hi ha resultats de la cerca.</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Xat</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Gràfics</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Oficina</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Lectura</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Desenvolupament</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <source>Games</source>
        <translation>Jocs</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Altres</translation>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmeu-ho</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation>Segur que voleu desinstal·lar %1?</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>Elimina de l&apos;escriptori</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>Elimina de l&apos;acoblador</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>Desinstal·la</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation>Inhabilita l&apos;escalatge de la pantalla</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Obre</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>Enviar a l&apos;escriptori</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>Envia a l&apos;acoblador</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>Eliminar de l&apos;arrencada</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>Afegir a l&apos;arrencada</translation>
    </message>
    <message>
        <source>Use a proxy</source>
        <translation>Utilitza un servidor intermediari</translation>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation>Totes les aplicacions</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Xat</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Gràfics</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Jocs</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Oficina</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Lectura</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Desenvolupament</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Altres</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>Ordinador</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documents</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Imatges</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Baixades</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Bloqueja</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Surt</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reinicia</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspèn</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Atura</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Enrere</translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>Ordinador</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Atura</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Bloqueja</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Surt</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reinicia</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspèn</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Enrere</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documents</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Imatges</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Baixades</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>Ordinador</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Baixades</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configuració</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Imatges</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documents</translation>
    </message>
    <message>
        <source>Power</source>
        <translation>Energia</translation>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation>Totes les categories</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Enrere</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmeu-ho</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation>Segur que voleu desinstal·lar %1?</translation>
    </message>
</context>
</TS>
